@@ -4,11 +4,11 @@ from pythautomata.base_types.state import State
 from pythautomata.base_types.alphabet import Alphabet
 from pythautomata.base_types.sequence import Sequence
 from pythautomata.base_types.symbol import Symbol
-from pythautomata.abstract.finite_automaton import FiniteAutomaton
+from pythautomata.abstract.finite_automaton import FiniteAutomaton, FiniteAutomataComparator
 from pythautomata.exceptions.unknown_symbols_exception import UnknownSymbolsException
 from pythautomata.exceptions.non_deterministic_states_exception import NonDeterministicStatesException
 from pythautomata.model_exporters.encoded_file_exporting_strategy import EncodedFileExportingStrategy
-from pythautomata.abstract.finite_automata_comparator import FiniteAutomataComparator
+
 
 class DeterministicFiniteAutomaton(FiniteAutomaton):
     """
@@ -21,7 +21,8 @@ class DeterministicFiniteAutomaton(FiniteAutomaton):
     initial_state: State
         Initial state of the DFA. Also included in "states"
     """
-    def __init__(self, alphabet: Alphabet, initial_state: State, states: set[State], comparator:FiniteAutomataComparator, name: str = None,
+
+    def __init__(self, alphabet: Alphabet, initial_state: State, states: set[State], comparator: FiniteAutomataComparator, name: str = None,
                  exportingStrategies: list = [EncodedFileExportingStrategy()], hole: State = State("Hole")):
         self.states = states
         for state in self.states:
@@ -41,13 +42,22 @@ class DeterministicFiniteAutomaton(FiniteAutomaton):
             actual_state = actual_state.next_state_for(symbol)
         return actual_state.is_final
 
+    @property
+    def initial_states(self) -> frozenset:
+        return frozenset([self.initial_state])
+
+    @property
+    def hole(self):
+        return self._hole
+
     def _set_hole(self, hole: State) -> None:
-        self.hole = hole
+        self._hole = hole
         # hole's hole state is itself
-        self.hole.add_hole_transition(self.hole)
+        self._hole.add_hole_transition(self.hole)
 
     def _veirify_state(self, state: State, alphabet: Alphabet) -> None:
-        self._verify_transition_symbols_in_alphabet(state.transitions, alphabet)
+        self._verify_transition_symbols_in_alphabet(
+            state.transitions, alphabet)
         self._verify_state_is_deterministic(state)
 
     def _verify_transition_symbols_in_alphabet(self, transitions: dict[Symbol, set['State']], alphabet: Alphabet) -> None:
@@ -56,4 +66,4 @@ class DeterministicFiniteAutomaton(FiniteAutomaton):
 
     def _verify_state_is_deterministic(self, state: State) -> None:
         if not state.is_deterministic:
-            raise NonDeterministicStatesException()
\ No newline at end of file
+            raise NonDeterministicStatesException()
