@@ -3,7 +3,7 @@ from pythautomata.base_types.symbol import SymbolStr
 from pythautomata.base_types.alphabet import Alphabet
 from pythautomata.automata.deterministic_finite_automaton import DeterministicFiniteAutomaton as DFA
 from pythautomata.automata.non_deterministic_finite_automaton import NondeterministicFiniteAutomaton as NFA
-from pythautomata.model_comparators.nfa_hopcroft_karp_comparison_strategy import NFAHopcroftKarpComparisonStrategy as NFAComparator
+from pythautomata.model_comparators.hopcroft_karp_comparison_strategy import HopcroftKarpComparisonStrategy as NFAComparator
 from pythautomata.model_comparators.dfa_comparison_strategy import DFAComparisonStrategy as DFAComparator
 
 binaryAlphabet = Alphabet(frozenset((SymbolStr('0'), SymbolStr('1'))))
@@ -26,6 +26,8 @@ d = abcdeAlphabet['d']
 e = abcdeAlphabet['e']
 
 #TODO: DOCUMENT
+
+
 class OtherAutomata:
 
     @staticmethod
@@ -99,8 +101,8 @@ class OtherAutomata:
         state5.add_transition(one, state5)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1, state2, state3,
-                                    state4, state5]), comparator, "Automaton 1")
+                   set([state0, state1, state2, state3,
+                        state4, state5]), comparator, "Automaton 1")
 
     @staticmethod
     def get_automaton_1_minimized():
@@ -115,7 +117,7 @@ class OtherAutomata:
         state2.add_transition(one, state2)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1, state2]), comparator, "Automaton 1 minimized")
+                   set([state0, state1, state2]), comparator, "Automaton 1 minimized")
 
     @staticmethod
     def get_automaton_2():
@@ -129,7 +131,7 @@ class OtherAutomata:
         state3.add_transition(zero, state2)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1, state2, state3]), comparator, "Automaton 2")
+                   set([state0, state1, state2, state3]), comparator, "Automaton 2")
 
     @staticmethod
     def get_automaton_2_minimized():
@@ -141,7 +143,7 @@ class OtherAutomata:
         state1_and_state3.add_transition(zero, state2)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1_and_state3, state2]), comparator, "Automaton 2 minimized")
+                   set([state0, state1_and_state3, state2]), comparator, "Automaton 2 minimized")
 
     @staticmethod
     def get_automaton_3():
@@ -167,8 +169,8 @@ class OtherAutomata:
         state7.add_transition(one, state6)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state1,
-                               set([state1, state2, state3, state4, state5,
-                                    state6, state7]), comparator, "Automaton 3")
+                   set([state1, state2, state3, state4, state5,
+                        state6, state7]), comparator, "Automaton 3")
 
     @staticmethod
     def get_automaton_3_minimized():
@@ -191,8 +193,8 @@ class OtherAutomata:
         state7.add_transition(one, state6)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state1_and_state2,
-                               set([state1_and_state2, state3, state4, state5,
-                                    state6, state7]), comparator, "Automaton 3 minimized")
+                   set([state1_and_state2, state3, state4, state5,
+                        state6, state7]), comparator, "Automaton 3 minimized")
 
     @staticmethod
     def get_automaton_4():
@@ -226,9 +228,9 @@ class OtherAutomata:
         state_f.add_transition(one, state_g)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state_i,
-                               set([state_i, state_d, state_c, state_a, state_b,
-                                    state_g, state_e, state_h, state_f]), comparator, 
-                                    "Automaton 4")
+                   set([state_i, state_d, state_c, state_a, state_b,
+                        state_g, state_e, state_h, state_f]), comparator,
+                   "Automaton 4")
 
     @staticmethod
     def get_automaton_4_minimized():
@@ -259,8 +261,8 @@ class OtherAutomata:
         state_h_and_f.add_transition(one, state_g)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state_i,
-                               set([state_i, state_d, state_c, state_a, state_b, state_g,
-                                    state_e, state_h_and_f]), comparator, "Automaton 4 minimized")
+                   set([state_i, state_d, state_c, state_a, state_b, state_g,
+                        state_e, state_h_and_f]), comparator, "Automaton 4 minimized")
 
     @staticmethod
     def get_non_minimizable_automaton_1():
@@ -279,7 +281,7 @@ class OtherAutomata:
         state3.add_transition(one, state1)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1, state2, state3]), comparator, "Non-minimizable automaton 1")
+                   set([state0, state1, state2, state3]), comparator, "Non-minimizable automaton 1")
 
     @staticmethod
     def get_non_minimizable_automaton_2():
@@ -291,7 +293,7 @@ class OtherAutomata:
         state1.add_transition(one, state0)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1]), comparator, "Non-minimizable automaton 2")
+                   set([state0, state1]), comparator, "Non-minimizable automaton 2")
 
     @staticmethod
     def get_non_minimizable_automaton_3():
@@ -305,7 +307,7 @@ class OtherAutomata:
         state2.add_transition(one, state0)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1, state2]), comparator, "Non-minimizable automaton 3")
+                   set([state0, state1, state2]), comparator, "Non-minimizable automaton 3")
 
     @staticmethod
     def get_nfa_1():
@@ -318,7 +320,7 @@ class OtherAutomata:
         state1.add_transition(one, state2)
         comparator = NFAComparator()
         return NFA(binaryAlphabet, frozenset({state0}),
-                               set([state0, state1, state2]), comparator, "NFA 1")
+                   set([state0, state1, state2]), comparator, "NFA 1")
 
     @staticmethod
     def get_dfa_1():
@@ -333,7 +335,7 @@ class OtherAutomata:
         state0_2.add_transition(one, state0)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state0_1, state0_2]), comparator, "DFA 1")
+                   set([state0, state0_1, state0_2]), comparator, "DFA 1")
 
     @staticmethod
     def get_nfa_2():
@@ -350,7 +352,7 @@ class OtherAutomata:
         state2.add_transition(one, state2)
         comparator = NFAComparator()
         return NFA(binaryAlphabet, frozenset({state0}),
-                               set([state0, state1, state2]), comparator, "NFA 2")
+                   set([state0, state1, state2]), comparator, "NFA 2")
 
     @staticmethod
     def get_dfa_2():
@@ -365,7 +367,7 @@ class OtherAutomata:
         state1_2.add_transition(one, state1_2)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1, state1_2]), comparator, "DFA 2")
+                   set([state0, state1, state1_2]), comparator, "DFA 2")
 
     @staticmethod
     def get_nfa_3():
@@ -378,7 +380,7 @@ class OtherAutomata:
         state1.add_transition(one, state1)
         comparator = NFAComparator()
         return NFA(binaryAlphabet, frozenset({state0}),
-                               set([state0, state1]), comparator, "NFA 3")
+                   set([state0, state1]), comparator, "NFA 3")
 
     @staticmethod
     def get_dfa_3():
@@ -392,7 +394,7 @@ class OtherAutomata:
         state0_1.add_transition(one, state0_1)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, state0,
-                               set([state0, state1, state0_1]), comparator, "DFA 3")
+                   set([state0, state1, state0_1]), comparator, "DFA 3")
 
     @staticmethod
     def get_nfa_4():
@@ -419,8 +421,8 @@ class OtherAutomata:
 
         comparator = NFAComparator()
         return NFA(abcAlphabet, frozenset({state0}),
-                               set([state0, state1, state2, state3,
-                                    state4, state5, state6]), comparator, "NFA 4")
+                   set([state0, state1, state2, state3,
+                        state4, state5, state6]), comparator, "NFA 4")
 
     @staticmethod
     def get_dfa_4():
@@ -473,10 +475,10 @@ class OtherAutomata:
 
         comparator = DFAComparator()
         return DFA(abcAlphabet, state0,
-                               set([state1, state4, state2, state4_3,
-                                    state0, state4_6, state3_5, state2_1,
-                                    state2_4_6_1, state1_0, state4_3_1_0,
-                                    state5_3_4_1_0, state2_4]), comparator, "DFA 4")
+                   set([state1, state4, state2, state4_3,
+                        state0, state4_6, state3_5, state2_1,
+                        state2_4_6_1, state1_0, state4_3_1_0,
+                        state5_3_4_1_0, state2_4]), comparator, "DFA 4")
 
     @staticmethod
     def get_nfa_5():
@@ -494,7 +496,7 @@ class OtherAutomata:
         state2.add_transition(d, state2)
         comparator = NFAComparator()
         return NFA(abcdeAlphabet, frozenset({state0}),
-                               set([state0, state1, state2]), comparator, "NFA 5")
+                   set([state0, state1, state2]), comparator, "NFA 5")
 
     @staticmethod
     def get_dfa_5():
@@ -516,7 +518,7 @@ class OtherAutomata:
         state1_2.add_transition(e, state1)
         comparator = DFAComparator()
         return DFA(abcdeAlphabet, state0,
-                               set([state0, state1, state2, state1_2]), comparator, "DFA 5")
+                   set([state0, state1, state2, state1_2]), comparator, "DFA 5")
 
     # Definition: Recognizes a program workflow.
     @staticmethod
@@ -529,7 +531,7 @@ class OtherAutomata:
         stateB.add_transition(one, stateB)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, stateA,
-                               set([stateA, stateB]), comparator, "Program workflow automaton")
+                   set([stateA, stateB]), comparator, "Program workflow automaton")
 
     # Definition: Recognizes e-commerce(taken from:
     # https://pdfs.semanticscholar.org/9cb9/74b6ece3e3fc2eab4f9cf0843bfc570df4a9.pdf).
@@ -593,8 +595,8 @@ class OtherAutomata:
         state7.add_transition(a, state6)
         comparator = DFAComparator()
         return DFA(alphabet, state0,
-                               set([state0, state1, state2, state3, state4, state5,
-                                    state6, state7]), comparator, "E-commerce automaton")
+                   set([state0, state1, state2, state3, state4, state5,
+                        state6, state7]), comparator, "E-commerce automaton")
 
     # Definition: Recognizes e-commerce(taken from:
     # https://pdfs.semanticscholar.org/9cb9/74b6ece3e3fc2eab4f9cf0843bfc570df4a9.pdf).
@@ -656,8 +658,8 @@ class OtherAutomata:
         state7.add_transition(a, state6)
         comparator = NFAComparator()
         return NFA(alphabet, frozenset({state0}),
-                               set([state0, state1, state2, state3, state4, state5,
-                                    state6, state7]), comparator, "Modified E-commerce automaton")
+                   set([state0, state1, state2, state3, state4, state5,
+                        state6, state7]), comparator, "Modified E-commerce automaton")
 
     # Definition: Recognizes e-commerce, reduced version (taken from:
     # https://pdfs.semanticscholar.org/9cb9/74b6ece3e3fc2eab4f9cf0843bfc570df4a9.pdf).
@@ -701,9 +703,9 @@ class OtherAutomata:
         state4.add_transition(e, state4)
         comparator = DFAComparator()
         return DFA(alphabet, state0,
-                               set([state0, state1, state2, state3, state4]),
-                               comparator,
-                               "Reduced E-commerce automaton")
+                   set([state0, state1, state2, state3, state4]),
+                   comparator,
+                   "Reduced E-commerce automaton")
 
     # Definition: Recognizes strings not containing 'bbb' (not minimized).
     @staticmethod
@@ -734,9 +736,9 @@ class OtherAutomata:
         state7.add_transition(b, state5)
         comparator = DFAComparator()
         return DFA(abAlphabet, state0,
-                               set([state0, state1, state2, state3, state4, state5,
-                                    state6, state7]), comparator,
-                                    "Dolzhenko-Jonoska automaton")
+                   set([state0, state1, state2, state3, state4, state5,
+                        state6, state7]), comparator,
+                   "Dolzhenko-Jonoska automaton")
 
     # Definition: (a|b)*
     @staticmethod
@@ -763,7 +765,7 @@ class OtherAutomata:
         state1.add_transition(c, state1)
         comparator = DFAComparator()
         return DFA(abcAlphabet, state0,
-                               set([state0, state1]), comparator, "ab with cs automaton")
+                   set([state0, state1]), comparator, "ab with cs automaton")
 
     # Definition: (ab)*
     @staticmethod
@@ -776,7 +778,7 @@ class OtherAutomata:
         state1.add_transition(b, state0)
         comparator = DFAComparator()
         return DFA(abAlphabet, state0,
-                               set([state0, state1]), comparator, "ab automaton")
+                   set([state0, state1]), comparator, "ab automaton")
 
     # Definition: (.*0)
     @staticmethod
@@ -792,7 +794,7 @@ class OtherAutomata:
         stateC.add_transition(one, stateC)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, stateA,
-                               set([stateA, stateB, stateC]), comparator, "Zero ending automaton")
+                   set([stateA, stateB, stateC]), comparator, "Zero ending automaton")
 
     # Definition: (.*a), with {a, b, c} alphabet.
     @staticmethod
@@ -810,7 +812,7 @@ class OtherAutomata:
         state1.add_transition(c, state1)
         comparator = DFAComparator()
         return DFA(abcAlphabet, state0,
-                               set([state0, state1]), comparator, "a ending with cs automaton")
+                   set([state0, state1]), comparator, "a ending with cs automaton")
 
     # Definition: (.*a), with {a, b} alphabet.
     @staticmethod
@@ -825,7 +827,7 @@ class OtherAutomata:
         state1.add_transition(b, state1)
         comparator = DFAComparator()
         return DFA(abAlphabet, state0,
-                               set([state0, state1]), comparator, "a ending automaton")
+                   set([state0, state1]), comparator, "a ending automaton")
 
     # Definition: (..*0)
     @staticmethod
@@ -838,7 +840,7 @@ class OtherAutomata:
         stateB.add_transition(one, stateA)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, stateA,
-                               set([stateA, stateB]), comparator, "Non-empty zero ending automaton")
+                   set([stateA, stateB]), comparator, "Non-empty zero ending automaton")
 
     # Definition: (..*1)
     @staticmethod
@@ -851,7 +853,7 @@ class OtherAutomata:
         stateB.add_transition(one, stateB)
         comparator = DFAComparator()
         return DFA(binaryAlphabet, stateA,
-                               set([stateA, stateB]), comparator, "Non-empty one ending automaton")
+                   set([stateA, stateB]), comparator, "Non-empty one ending automaton")
 
     # Definition: (ab)*a
     @staticmethod
@@ -884,8 +886,8 @@ class OtherAutomata:
         state7.add_transition(b, state2)
         comparator = DFAComparator()
         return DFA(abAlphabet, state0,
-                               set([state0, state1, state2, state3, state4, state5,
-                                    state6, state7]), comparator, "Complex ab prefixed automaton")
+                   set([state0, state1, state2, state3, state4, state5,
+                        state6, state7]), comparator, "Complex ab prefixed automaton")
 
     # Definition: (ab)*a
     @staticmethod
@@ -898,7 +900,7 @@ class OtherAutomata:
         state1.add_transition(b, state0)
         comparator = DFAComparator()
         return DFA(abAlphabet, state0,
-                               set([state0, state1]), comparator, "Simpler ab prefixed automaton")
+                   set([state0, state1]), comparator, "Simpler ab prefixed automaton")
 
     @staticmethod
     def get_alternating_bit_protocol_automaton():
@@ -920,9 +922,9 @@ class OtherAutomata:
         state3.add_transition(a, state0)
         comparator = DFAComparator()
         return DFA(abcdAlphabet, state0,
-                               set([state0, state1, state2, state3]),
-                               comparator,
-                               "Alternating bit protocol automaton")
+                   set([state0, state1, state2, state3]),
+                   comparator,
+                   "Alternating bit protocol automaton")
 
     @staticmethod
     def get_alternating_bit_protocol_z_automaton():
@@ -951,9 +953,9 @@ class OtherAutomata:
         state3.add_transition(e, state3)
         comparator = DFAComparator()
         return DFA(alphabet, state0,
-                               set([state0, state1, state2, state3]),
-                               comparator,
-                               "Alternating bit protocol z automaton")
+                   set([state0, state1, state2, state3]),
+                   comparator,
+                   "Alternating bit protocol z automaton")
 
     # Definition: {}
     @staticmethod
@@ -965,7 +967,7 @@ class OtherAutomata:
         stateA.add_transition(b, stateA)
         comparator = DFAComparator()
         return DFA(abAlphabet, stateA,
-                               set([stateA]), comparator, "Empty automaton")
+                   set([stateA]), comparator, "Empty automaton")
 
     # Definition: Σ*
     @staticmethod
@@ -977,7 +979,7 @@ class OtherAutomata:
         stateA.add_transition(b, stateA)
         comparator = DFAComparator()
         return DFA(abAlphabet, stateA,
-                               set([stateA]), comparator, "Sigma-star automaton")
+                   set([stateA]), comparator, "Sigma-star automaton")
 
     # Definition: uneven number of as
     @staticmethod
@@ -992,7 +994,7 @@ class OtherAutomata:
         stateB.add_transition(b, stateB)
         comparator = DFAComparator()
         return DFA(abAlphabet, stateA,
-                               set([stateA, stateB]), comparator, "Uneven number of as")
+                   set([stateA, stateB]), comparator, "Uneven number of as")
 
     # Definition: uneven number of symbols
     @staticmethod
@@ -1007,7 +1009,7 @@ class OtherAutomata:
         stateD.add_transition(b, stateC)
         comparator = DFAComparator()
         return DFA(abAlphabet, stateC,
-                               set([stateC, stateD]), comparator, "Uneven number of symbols")
+                   set([stateC, stateD]), comparator, "Uneven number of symbols")
 
     # Definition: uneven number of as and symbols
     @staticmethod
@@ -1029,9 +1031,9 @@ class OtherAutomata:
         stateBD.add_transition(b, stateBC)
         comparator = DFAComparator()
         return DFA(abAlphabet, stateAC,
-                               set([stateAC, stateAD, stateBC, stateBD]),
-                               comparator,
-                               "Uneven number of as and symbols")
+                   set([stateAC, stateAD, stateBC, stateBD]),
+                   comparator,
+                   "Uneven number of as and symbols")
 
     # Definition: uneven number of as or symbols
     @staticmethod
@@ -1053,6 +1055,6 @@ class OtherAutomata:
         stateBD.add_transition(b, stateBC)
         comparator = DFAComparator()
         return DFA(abAlphabet, stateAC,
-                               set([stateAC, stateAD, stateBC, stateBD]),
-                               comparator,
-                               "Uneven number of as or symbols")
+                   set([stateAC, stateAD, stateBC, stateBD]),
+                   comparator,
+                   "Uneven number of as or symbols")
